Index: /anuga_core/source/anuga/abstract_2d_finite_volumes/domain.py
===================================================================
--- /anuga_core/source/anuga/abstract_2d_finite_volumes/domain.py	(revision 4568)
+++ /anuga_core/source/anuga/abstract_2d_finite_volumes/domain.py	(revision 4569)
@@ -960,5 +960,5 @@
         # self.timestep is calculated from speed of characteristics
         # Apply CFL condition here
-        timestep = min(self.CFL*self.timestep,max_timestep)
+        timestep = min(self.CFL*self.timestep, max_timestep)
 
         #Record maximal and minimal values of timestep for reporting
Index: /anuga_core/source/anuga/abstract_2d_finite_volumes/quantity.py
===================================================================
--- /anuga_core/source/anuga/abstract_2d_finite_volumes/quantity.py	(revision 4568)
+++ /anuga_core/source/anuga/abstract_2d_finite_volumes/quantity.py	(revision 4569)
@@ -692,5 +692,5 @@
 
 
-        #Call fit_interpolate.fit function
+        # Call fit_interpolate.fit function
         args = (coordinates, triangles, points, values)
         kwargs = {'data_origin': data_georef.get_origin(),
@@ -699,24 +699,27 @@
                   'verbose': verbose}
 
-        #print kwargs
-
-        #FIXME(dsg):Why is this catched? fit_to_mesh handles caching.
-        if use_cache is True:
-            try:
-                from caching import cache
-            except:
-                msg = 'Caching was requested, but caching module'+\
-                      'could not be imported'
-                raise msg
-
-            vertex_attributes = cache(fit_to_mesh,
-                                      args, kwargs,
-                                      verbose=verbose,
-                                      compression=False)
-        else:
-            vertex_attributes = apply(fit_to_mesh,
-                                      args, kwargs)
-
-        #Call underlying method using array values
+
+        # FIXME(dsg):Why is this catched? fit_to_mesh handles caching.
+        # Fair enough - I have commented it out 28/6/7 (Ole)
+        #if use_cache is True:
+        #    try:
+        #        from caching import cache
+        #    except:
+        #        msg = 'Caching was requested, but caching module'+\
+        #              'could not be imported'
+        #        raise msg
+        #
+        #    vertex_attributes = cache(fit_to_mesh,
+        #                              args, kwargs,
+        #                              verbose=verbose,
+        #                              compression=False)
+        #else:
+        #    vertex_attributes = apply(fit_to_mesh,
+        #                              args, kwargs)
+
+        vertex_attributes = apply(fit_to_mesh,
+                                  args, kwargs)        
+
+        # Call underlying method using array values
         self.set_values_from_array(vertex_attributes,
                                    location, indices, verbose)
@@ -747,5 +750,5 @@
         triangles = self.domain.triangles      #FIXME
             
-        vertex_attributes = fit_to_mesh(coordinates, triangles,filename,
+        vertex_attributes = fit_to_mesh(coordinates, triangles, filename,
                                         alpha=alpha,
                                         attribute_name=attribute_name,
@@ -754,5 +757,5 @@
                                         max_read_lines=max_read_lines)
                                             
-        #Call underlying method using array values
+        # Call underlying method using array values
         self.set_values_from_array(vertex_attributes,
                                    location, indices, verbose)
Index: /anuga_core/source/anuga/fit_interpolate/fit.py
===================================================================
--- /anuga_core/source/anuga/fit_interpolate/fit.py	(revision 4568)
+++ /anuga_core/source/anuga/fit_interpolate/fit.py	(revision 4569)
@@ -316,4 +316,5 @@
               List of coordinate pairs [x, y] of
 	      data points or an nx2 Numeric array or a Geospatial_data object
+              or filename (txt, csv, pts?)
           z: Single 1d vector or array of data at the point_coordinates.
           
@@ -324,5 +325,6 @@
             assert point_origin is None, msg
             filename = point_coordinates_or_filename
-            for i,geo_block in enumerate(Geospatial_data(filename,
+            
+            for i, geo_block in enumerate(Geospatial_data(filename,
                                               max_read_lines=max_read_lines,
                                               load_file_now=False,
@@ -468,15 +470,15 @@
 
 def _fit_to_mesh(vertex_coordinates,
-                triangles,
-                point_coordinates, # this can also be a .csv/.txt file name
-                point_attributes=None,
-                alpha=DEFAULT_ALPHA,
-                verbose=False,
-                acceptable_overshoot=1.01,
-                mesh_origin=None,
-                data_origin=None,
-                max_read_lines=None,
-                attribute_name=None,
-                use_cache = False):
+                 triangles,
+                 point_coordinates, # this can also be a .csv/.txt file name
+                 point_attributes=None,
+                 alpha=DEFAULT_ALPHA,
+                 verbose=False,
+                 acceptable_overshoot=1.01,
+                 mesh_origin=None,
+                 data_origin=None,
+                 max_read_lines=None,
+                 attribute_name=None,
+                 use_cache = False):
     """
     Fit a smooth surface to a triangulation,
@@ -495,5 +497,6 @@
 
           point_coordinates: List of coordinate pairs [x, y] of data points
-          (or an nx2 Numeric array)
+          (or an nx2 Numeric array). This can also be a .csv/.txt file name
+          FIXME (Ole): Can't it be a pts file too?
 
           alpha: Smoothing parameter.
Index: /anuga_core/source/anuga/geospatial_data/geospatial_data.py
===================================================================
--- /anuga_core/source/anuga/geospatial_data/geospatial_data.py	(revision 4568)
+++ /anuga_core/source/anuga/geospatial_data/geospatial_data.py	(revision 4569)
@@ -49,5 +49,5 @@
         data_points: x,y coordinates in meters. Type must be either a
         sequence of 2-tuples or an Mx2 Numeric array of floats.  A file name
-        can also be passed in here.
+        with extension .txt, .cvs or .pts can also be passed in here.
 
         attributes: Associated values for each data point. The type
@@ -147,5 +147,6 @@
                 msg = 'No file specified yet a delimiter is provided!'
                 raise ValueError, msg
-            file_name = None
+            file_name = None #FIXME (Ole): Isn't this line superfluous
+            
             if latitudes is not None or longitudes is not None or \
                    points_are_lats_longs:
@@ -748,6 +749,6 @@
 
     def __iter__(self):
-        """
-        read in the header and save the file pointer position
+        """Read in the header, number_of_points and save the
+        file pointer position
         """
 
@@ -756,8 +757,10 @@
         #FIXME - what to do if the file isn't there
 
-        if self.file_name[-4:]== ".xya":
+        if self.file_name[-4:] == ".xya":
+            # FIXME (Ole): shouldn't the xya format be replaced by txt/csv?
+
             #let's just read it all
             pass
-        elif self.file_name[-4:]== ".pts":
+        elif self.file_name[-4:] == ".pts":
             
             # see if the file is there.  Throw a QUIET IO error if it isn't
@@ -770,12 +773,20 @@
             self.blocking_georef, self.blocking_keys, self.last_row = \
                      _read_pts_file_header(self.fid, self.verbose)
-            self.start_row=0
+            self.start_row = 0
             self.show_verbose = 0
-            self.verbose_block_size =  (self.last_row +10) /10
+            self.verbose_block_size = (self.last_row + 10)/10
+            
+            if self.verbose is True:
+                print 'Reading %d points (blocking) from file %s'\
+                      %(self.last_row,
+                        self.file_name)
+            
         else:
+            # It looks like the file is assumed to be a csv file
             file_pointer = open(self.file_name)
             self.header, self.file_pointer = \
                          _read_csv_file_header(file_pointer)
             self.blocking_georef = None # Used for reconciling zones
+            
         if self.max_read_lines is None:
             self.max_read_lines = MAX_READ_LINES
@@ -783,6 +794,9 @@
     
     def next(self):
-        # read a block, instanciate a new geospatial and return it
+        """ read a block, instanciate a new geospatial and return it"""
+        
         if self.file_name[-4:]== ".xya" :
+            # FIXME (Ole): shouldn't the xya format be replaced by txt/csv? 
+            
             if not hasattr(self,'finished_reading') or \
                    self.finished_reading is False:
@@ -814,5 +828,5 @@
             if self.verbose is True:
                 if self.show_verbose >= self.start_row and \
-                                       self.show_verbose < fin_row:
+                       self.show_verbose < fin_row:
                  print 'Doing %d of %d' %(self.start_row, self.last_row+10)
                  self.show_verbose += max(self.max_read_lines,
@@ -820,9 +834,9 @@
             #call stuff
             pointlist, att_dict, = \
-                   _read_pts_file_blocking( self.fid,
-                                            self.start_row,
-                                            fin_row,
-                                            self.blocking_keys
-                                            ) 
+                   _read_pts_file_blocking(self.fid,
+                                           self.start_row,
+                                           fin_row,
+                                           self.blocking_keys)
+            
             geo = Geospatial_data(pointlist, att_dict, self.blocking_georef)
             self.start_row = fin_row
@@ -923,4 +937,5 @@
                                                     longitudes=longitudes)
     return data_points, Geo_reference(zone=zone)
+
     
 def _read_pts_file(file_name, verbose=False):
@@ -1089,6 +1104,5 @@
 def _read_pts_file_header(fid, verbose=False):
 
     """
     Read the geo_reference of a .pts file
     """
     
@@ -1089,6 +1104,5 @@
 def _read_pts_file_header(fid, verbose=False):
 
-    """
-    Read the geo_reference of a .pts file
+    """Read the geo_reference and number_of_points from a .pts file
     """
     
